@@ -1,6 +1,7 @@
 import re
 from typing import Any, Dict, List, Tuple, Union
 
+from django.conf import settings
 from django.core.serializers.json import DjangoJSONEncoder
 from rest_framework import fields, serializers
 
@@ -57,14 +58,20 @@ class ProcessingMixin:
         serializer: SerializerType,
         renderer_context: Dict[str, Any],
         prefix: str = '',
+        extra_types: Dict[str, Any] = {},
     ):
         self.serializer = serializer
         if self._is_list_serializer(serializer):
-            self.fields = self._filter_fields(serializer.child.get_fields().items())
+            self.fields = self._filter_fields(serializer.child.fields.items())
         else:
-            self.fields = self._filter_fields(serializer.get_fields().items())
+            self.fields = self._filter_fields(serializer.fields.items())
         self.renderer_context = renderer_context
         self.prefix = prefix
+        self.extra_types = extra_types
+        self.extra_types.update(
+            getattr(settings, 'DRF_REACT_TEMPLATE_TYPE_MAP', {})
+        )
+        self.TYPE_MAP.update(self.extra_types)
 
     def _get_type_map_value(self, field: SerializerType):
         result = {
@@ -114,8 +121,9 @@ class SchemaProcessor(ProcessingMixin):
         serializer: SerializerType,
         renderer_context: Dict[str, Any],
         prefix: str = '',
+        extra_types: Dict[str, Any] = {},
     ):
-        super().__init__(serializer, renderer_context, prefix)
+        super().__init__(serializer, renderer_context, prefix, extra_types)
         self.fields_to_be_removed = set()
         self.fields_to_be_kept = set()
 
@@ -360,7 +368,7 @@ class UiSchemaProcessor(ProcessingMixin):
 
     def _get_style_dict(self, field) -> Dict[str, Any]:
         style_dict = {}
-        for k, v in self._get_style_dict(field).items():
+        for k, v in field.style.items():
             if not k.startswith("schema:") and k not in STYLE_KEYS_TO_IGNORE:
                 style_dict[k] = v
         return style_dict
@@ -386,9 +394,7 @@ class UiSchemaProcessor(ProcessingMixin):
             result['ui:widget'] = widget
         if help_text:
             result['ui:help'] = help_text
-        result.update(
-            {k: v for k, v in field.style.items() if k not in STYLE_KEYS_TO_IGNORE}
-        )
+        result.update(self._get_style_dict(field))
         return result
 
     def _get_all_ui_properties(self) -> Dict[str, Any]:
@@ -403,12 +409,14 @@ class UiSchemaProcessor(ProcessingMixin):
             return {
                 'items': {
                     **{'ui:order': self._field_order()},
+                    **self._get_style_dict(self.serializer),
                     **self._get_all_ui_properties(),
                 }
             }
         else:
             return {
                 **{'ui:order': self._field_order()},
+                **self._get_style_dict(self.serializer),
                 **self._get_all_ui_properties(),
             }
 
